@@ -1,6 +1,6 @@
 package Class::Delegation;
 
-use version; $VERSION = qv('1.7.1');
+our $VERSION = '1.9.0';
 
 use strict;
 use Carp;
@@ -177,7 +177,8 @@ sub _class_for {
 	return "Class::Delegation::${subclass}::${type}";
 }
 
-package SELF;
+package # Hide from CPAN indexer
+SELF;
 
 sub DESTROY {}
 sub AUTOLOAD {
@@ -380,7 +381,7 @@ Class::Delegation - Object-oriented delegation
 
 =head1 VERSION
 
-This document describes version 1.06 of Class::Delegation,
+This document describes version 1.9.0 of Class::Delegation
 released April 23, 2002.
 
 =head1 SYNOPSIS
@@ -1065,7 +1066,7 @@ acts as a collective front-end for several others. For example:
                   
 
 The Bilateral class now forwards all I<class> method calls that are prefixed
-with C<"left_..."> to the Lvorotatory class, and all those prefixed with
+with C<"left_..."> to the Laevorotatory class, and all those prefixed with
 C<"right_..."> to the Dextrorotatory class. Any calls that cannot be dispatched
 are caught and ignored (with a warning) by the C<AUTOLOAD>.
 
